import type { PropType, ExtractPropTypes, UnwrapRef, Plugin, WatchStopHandle } from 'vue';
import type { RenderEmptyHandler } from './renderEmpty';
import type { Locale } from '../locale-provider';
import type { TransformCellTextProps } from '../table/interface';
import type { MaybeRef } from '../_util/type';
export declare type SizeType = 'small' | 'middle' | 'large' | undefined;
export interface CSPConfig {
    nonce?: string;
}
export type { RenderEmptyHandler };
export declare type Direction = 'ltr' | 'rtl';
export interface ConfigConsumerProps {
    getTargetContainer?: () => HTMLElement;
    getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
    rootPrefixCls?: string;
    getPrefixCls: (suffixCls?: string, customizePrefixCls?: string) => string;
    renderEmpty: RenderEmptyHandler;
    transformCellText?: (tableProps: TransformCellTextProps) => any;
    csp?: CSPConfig;
    autoInsertSpaceInButton?: boolean;
    input?: {
        autoComplete?: string;
    };
    locale?: Locale;
    pageHeader?: {
        ghost: boolean;
    };
    componentSize?: SizeType;
    direction?: 'ltr' | 'rtl';
    space?: {
        size?: SizeType | number;
    };
    virtual?: boolean;
    dropdownMatchSelectWidth?: boolean | number;
}
export declare const configConsumerProps: string[];
export declare const defaultPrefixCls = "ant";
declare type GlobalConfigProviderProps = {
    prefixCls?: MaybeRef<ConfigProviderProps['prefixCls']>;
};
declare const setGlobalConfig: (params: GlobalConfigProviderProps) => void;
export declare const globalConfig: () => {
    getPrefixCls: (suffixCls?: string, customizePrefixCls?: string) => string;
    getRootPrefixCls: (rootPrefixCls?: string, customizePrefixCls?: string) => string;
};
export declare const configProviderProps: {
    getTargetContainer: {
        type: PropType<() => HTMLElement>;
    };
    getPopupContainer: {
        type: PropType<(triggerNode: HTMLElement) => HTMLElement>;
    };
    prefixCls: StringConstructor;
    getPrefixCls: {
        type: PropType<(suffixCls?: string, customizePrefixCls?: string) => string>;
    };
    renderEmpty: {
        type: PropType<any>;
    };
    transformCellText: {
        type: PropType<(tableProps: any) => any>;
    };
    csp: {
        type: PropType<CSPConfig>;
    };
    autoInsertSpaceInButton: import("vue-types").VueTypeValidableDef<boolean>;
    locale: {
        type: PropType<any>;
    };
    pageHeader: {
        type: PropType<{
            ghost: boolean;
        }>;
    };
    componentSize: {
        type: PropType<SizeType>;
    };
    direction: {
        type: PropType<"ltr" | "rtl">;
    };
    space: {
        type: PropType<{
            size: SizeType | number;
        }>;
    };
    virtual: import("vue-types").VueTypeValidableDef<boolean>;
    dropdownMatchSelectWidth: {
        type: (BooleanConstructor | NumberConstructor)[];
        default: boolean;
    };
    form: {
        type: PropType<{
            requiredMark?: any;
        }>;
    };
};
export declare type ConfigProviderProps = Partial<ExtractPropTypes<typeof configProviderProps>>;
export declare const defaultConfigProvider: UnwrapRef<ConfigProviderProps>;
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            dropdownMatchSelectWidth: number | boolean;
        }> & Omit<Readonly<{
            getTargetContainer?: unknown;
            getPopupContainer?: unknown;
            prefixCls?: unknown;
            getPrefixCls?: unknown;
            renderEmpty?: unknown;
            transformCellText?: unknown;
            csp?: unknown;
            autoInsertSpaceInButton?: unknown;
            locale?: unknown;
            pageHeader?: unknown;
            componentSize?: unknown;
            direction?: unknown;
            space?: unknown;
            virtual?: unknown;
            dropdownMatchSelectWidth?: unknown;
            form?: unknown;
        } & {
            dropdownMatchSelectWidth: number | boolean;
        } & {
            form?: unknown;
            space?: {
                size: number | SizeType;
            };
            prefixCls?: string;
            getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
            getPrefixCls?: (suffixCls?: string, customizePrefixCls?: string) => string;
            getTargetContainer?: () => HTMLElement;
            direction?: "ltr" | "rtl";
            locale?: unknown;
            autoInsertSpaceInButton?: boolean;
            renderEmpty?: unknown;
            csp?: unknown;
            pageHeader?: {
                ghost: boolean;
            };
            transformCellText?: (tableProps: any) => any;
            componentSize?: SizeType;
            virtual?: boolean;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "dropdownMatchSelectWidth">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            getTargetContainer?: unknown;
            getPopupContainer?: unknown;
            prefixCls?: unknown;
            getPrefixCls?: unknown;
            renderEmpty?: unknown;
            transformCellText?: unknown;
            csp?: unknown;
            autoInsertSpaceInButton?: unknown;
            locale?: unknown;
            pageHeader?: unknown;
            componentSize?: unknown;
            direction?: unknown;
            space?: unknown;
            virtual?: unknown;
            dropdownMatchSelectWidth?: unknown;
            form?: unknown;
        } & {
            dropdownMatchSelectWidth: number | boolean;
        } & {
            form?: unknown;
            space?: {
                size: number | SizeType;
            };
            prefixCls?: string;
            getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
            getPrefixCls?: (suffixCls?: string, customizePrefixCls?: string) => string;
            getTargetContainer?: () => HTMLElement;
            direction?: "ltr" | "rtl";
            locale?: unknown;
            autoInsertSpaceInButton?: boolean;
            renderEmpty?: unknown;
            csp?: unknown;
            pageHeader?: {
                ghost: boolean;
            };
            transformCellText?: (tableProps: any) => any;
            componentSize?: SizeType;
            virtual?: boolean;
        }>, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            dropdownMatchSelectWidth: number | boolean;
        }> & {
            beforeCreate?: (() => void) | (() => void)[];
            created?: (() => void) | (() => void)[];
            beforeMount?: (() => void) | (() => void)[];
            mounted?: (() => void) | (() => void)[];
            beforeUpdate?: (() => void) | (() => void)[];
            updated?: (() => void) | (() => void)[];
            activated?: (() => void) | (() => void)[];
            deactivated?: (() => void) | (() => void)[];
            beforeDestroy?: (() => void) | (() => void)[];
            beforeUnmount?: (() => void) | (() => void)[];
            destroyed?: (() => void) | (() => void)[];
            unmounted?: (() => void) | (() => void)[];
            renderTracked?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            renderTriggered?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            errorCaptured?: ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>, info: string) => boolean | void) | ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>, info: string) => boolean | void)[];
        };
        $forceUpdate: () => void;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): WatchStopHandle;
    } & Readonly<{
        getTargetContainer?: unknown;
        getPopupContainer?: unknown;
        prefixCls?: unknown;
        getPrefixCls?: unknown;
        renderEmpty?: unknown;
        transformCellText?: unknown;
        csp?: unknown;
        autoInsertSpaceInButton?: unknown;
        locale?: unknown;
        pageHeader?: unknown;
        componentSize?: unknown;
        direction?: unknown;
        space?: unknown;
        virtual?: unknown;
        dropdownMatchSelectWidth?: unknown;
        form?: unknown;
    } & {
        dropdownMatchSelectWidth: number | boolean;
    } & {
        form?: unknown;
        space?: {
            size: number | SizeType;
        };
        prefixCls?: string;
        getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
        getPrefixCls?: (suffixCls?: string, customizePrefixCls?: string) => string;
        getTargetContainer?: () => HTMLElement;
        direction?: "ltr" | "rtl";
        locale?: unknown;
        autoInsertSpaceInButton?: boolean;
        renderEmpty?: unknown;
        csp?: unknown;
        pageHeader?: {
            ghost: boolean;
        };
        transformCellText?: (tableProps: any) => any;
        componentSize?: SizeType;
        virtual?: boolean;
    }> & import("vue").ShallowUnwrapRef<() => JSX.Element> & {} & {} & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    getTargetContainer?: unknown;
    getPopupContainer?: unknown;
    prefixCls?: unknown;
    getPrefixCls?: unknown;
    renderEmpty?: unknown;
    transformCellText?: unknown;
    csp?: unknown;
    autoInsertSpaceInButton?: unknown;
    locale?: unknown;
    pageHeader?: unknown;
    componentSize?: unknown;
    direction?: unknown;
    space?: unknown;
    virtual?: unknown;
    dropdownMatchSelectWidth?: unknown;
    form?: unknown;
} & {
    dropdownMatchSelectWidth: number | boolean;
} & {
    form?: unknown;
    space?: {
        size: number | SizeType;
    };
    prefixCls?: string;
    getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
    getPrefixCls?: (suffixCls?: string, customizePrefixCls?: string) => string;
    getTargetContainer?: () => HTMLElement;
    direction?: "ltr" | "rtl";
    locale?: unknown;
    autoInsertSpaceInButton?: boolean;
    renderEmpty?: unknown;
    csp?: unknown;
    pageHeader?: {
        ghost: boolean;
    };
    transformCellText?: (tableProps: any) => any;
    componentSize?: SizeType;
    virtual?: boolean;
}>, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    dropdownMatchSelectWidth: number | boolean;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & Plugin & {
    readonly config: typeof setGlobalConfig;
};
export default _default;
