import type { PropType, ExtractPropTypes } from 'vue';
import type { VueNode } from '../_util/type';
export interface CascaderOptionType {
    value?: string | number;
    label?: VueNode;
    disabled?: boolean;
    isLeaf?: boolean;
    loading?: boolean;
    children?: CascaderOptionType[];
    [key: string]: any;
}
export interface FieldNamesType {
    value?: string;
    label?: string;
    children?: string;
}
export interface FilledFieldNamesType {
    value: string;
    label: string;
    children: string;
}
export interface ShowSearchType {
    filter?: (inputValue: string, path: CascaderOptionType[], names: FilledFieldNamesType) => boolean;
    render?: (inputValue: string, path: CascaderOptionType[], prefixCls: string | undefined, names: FilledFieldNamesType) => VueNode;
    sort?: (a: CascaderOptionType[], b: CascaderOptionType[], inputValue: string, names: FilledFieldNamesType) => number;
    matchInputWidth?: boolean;
    limit?: number | false;
}
export interface EmptyFilteredOptionsType {
    disabled: boolean;
    [key: string]: any;
}
export interface FilteredOptionsType extends EmptyFilteredOptionsType {
    __IS_FILTERED_OPTION: boolean;
    path: CascaderOptionType[];
}
declare const cascaderProps: {
    /** 可选项数据源 */
    options: {
        type: PropType<CascaderOptionType[]>;
        default: any[];
    };
    /** 默认的选中项 */
    defaultValue: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    /** 指定选中项 */
    value: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    /** 选择完成后的回调 */
    /** 选择后展示的渲染函数 */
    displayRender: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    popupStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    /** 自定义浮层类名 */
    popupClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    /** 浮层预设位置：`bottomLeft` `bottomRight` `topLeft` `topRight` */
    popupPlacement: import("vue-types").VueTypeDef<"topLeft" | "topRight" | "bottomLeft" | "bottomRight"> & {
        default: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
    };
    /** 输入框占位文本*/
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    /** 输入框大小，可选 `large` `default` `small` */
    size: import("vue-types").VueTypeDef<"small" | "default" | "large">;
    /** 禁用*/
    disabled: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    /** 是否支持清除*/
    allowClear: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    showSearch: {
        type: PropType<boolean | ShowSearchType>;
        default: PropType<boolean | ShowSearchType>;
    };
    notFoundContent: import("vue-types").VueTypeValidableDef<VueNode>;
    loadData: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    /** 次级菜单的展开方式，可选 'click' 和 'hover' */
    expandTrigger: import("vue-types").VueTypeDef<"click" | "hover">;
    /** 当此项为 true 时，点选每级菜单选项值都会发生变化 */
    changeOnSelect: import("vue-types").VueTypeValidableDef<boolean>;
    /** 浮层可见变化时回调 */
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    inputPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    popupVisible: import("vue-types").VueTypeValidableDef<boolean>;
    fieldNames: {
        type: PropType<FieldNamesType>;
    };
    autofocus: import("vue-types").VueTypeValidableDef<boolean>;
    suffixIcon: import("vue-types").VueTypeValidableDef<VueNode>;
    showSearchRender: import("vue-types").VueTypeValidableDef<any>;
    onChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onPopupVisibleChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onFocus: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onBlur: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onSearch: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    'onUpdate:value': import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
};
export declare type CascaderProps = Partial<ExtractPropTypes<typeof cascaderProps>>;
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {
            sValue: any[];
            inputValue: string;
            inputFocused: boolean;
            sPopupVisible: boolean;
            flattenOptions: any[];
        };
        $props: Partial<{
            disabled: boolean;
            value: unknown[];
            onFocus: (...args: any[]) => any;
            onBlur: (...args: any[]) => any;
            onChange: (...args: any[]) => any;
            prefixCls: string;
            getPopupContainer: (...args: any[]) => any;
            options: CascaderOptionType[];
            placeholder: string;
            defaultValue: unknown[];
            displayRender: (...args: any[]) => any;
            transitionName: string;
            popupStyle: {
                [key: string]: any;
            };
            popupClassName: string;
            popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
            allowClear: boolean;
            showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
            loadData: (...args: any[]) => any;
            inputPrefixCls: string;
            onPopupVisibleChange: (...args: any[]) => any;
            onSearch: (...args: any[]) => any;
            "onUpdate:value": (...args: any[]) => any;
        }> & Omit<Readonly<{
            options?: unknown;
            defaultValue?: unknown;
            value?: unknown;
            displayRender?: unknown;
            transitionName?: unknown;
            popupStyle?: unknown;
            popupClassName?: unknown;
            popupPlacement?: unknown;
            placeholder?: unknown;
            size?: unknown;
            disabled?: unknown;
            allowClear?: unknown;
            showSearch?: unknown;
            notFoundContent?: unknown;
            loadData?: unknown;
            expandTrigger?: unknown;
            changeOnSelect?: unknown;
            prefixCls?: unknown;
            inputPrefixCls?: unknown;
            getPopupContainer?: unknown;
            popupVisible?: unknown;
            fieldNames?: unknown;
            autofocus?: unknown;
            suffixIcon?: unknown;
            showSearchRender?: unknown;
            onChange?: unknown;
            onPopupVisibleChange?: unknown;
            onFocus?: unknown;
            onBlur?: unknown;
            onSearch?: unknown;
            'onUpdate:value'?: unknown;
        } & {
            disabled: boolean;
            value: unknown[];
            prefixCls: string;
            options: CascaderOptionType[];
            placeholder: string;
            defaultValue: unknown[];
            transitionName: string;
            popupStyle: {
                [key: string]: any;
            };
            popupClassName: string;
            popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
            allowClear: boolean;
            showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
            inputPrefixCls: string;
        } & {
            size?: "small" | "default" | "large";
            onFocus?: (...args: any[]) => any;
            onBlur?: (...args: any[]) => any;
            onChange?: (...args: any[]) => any;
            getPopupContainer?: (...args: any[]) => any;
            notFoundContent?: VueNode;
            autofocus?: boolean;
            displayRender?: (...args: any[]) => any;
            loadData?: (...args: any[]) => any;
            expandTrigger?: "click" | "hover";
            changeOnSelect?: boolean;
            popupVisible?: boolean;
            fieldNames?: unknown;
            suffixIcon?: VueNode;
            showSearchRender?: any;
            onPopupVisibleChange?: (...args: any[]) => any;
            onSearch?: (...args: any[]) => any;
            "onUpdate:value"?: (...args: any[]) => any;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "disabled" | "value" | "onFocus" | "onBlur" | "onChange" | "prefixCls" | "getPopupContainer" | "options" | "placeholder" | "defaultValue" | "displayRender" | "transitionName" | "popupStyle" | "popupClassName" | "popupPlacement" | "allowClear" | "showSearch" | "loadData" | "inputPrefixCls" | "onPopupVisibleChange" | "onSearch" | "onUpdate:value">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            options?: unknown;
            defaultValue?: unknown;
            value?: unknown;
            displayRender?: unknown;
            transitionName?: unknown;
            popupStyle?: unknown;
            popupClassName?: unknown;
            popupPlacement?: unknown;
            placeholder?: unknown;
            size?: unknown;
            disabled?: unknown;
            allowClear?: unknown;
            showSearch?: unknown;
            notFoundContent?: unknown;
            loadData?: unknown;
            expandTrigger?: unknown;
            changeOnSelect?: unknown;
            prefixCls?: unknown;
            inputPrefixCls?: unknown;
            getPopupContainer?: unknown;
            popupVisible?: unknown;
            fieldNames?: unknown;
            autofocus?: unknown;
            suffixIcon?: unknown;
            showSearchRender?: unknown;
            onChange?: unknown;
            onPopupVisibleChange?: unknown;
            onFocus?: unknown;
            onBlur?: unknown;
            onSearch?: unknown;
            'onUpdate:value'?: unknown;
        } & {
            disabled: boolean;
            value: unknown[];
            prefixCls: string;
            options: CascaderOptionType[];
            placeholder: string;
            defaultValue: unknown[];
            transitionName: string;
            popupStyle: {
                [key: string]: any;
            };
            popupClassName: string;
            popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
            allowClear: boolean;
            showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
            inputPrefixCls: string;
        } & {
            size?: "small" | "default" | "large";
            onFocus?: (...args: any[]) => any;
            onBlur?: (...args: any[]) => any;
            onChange?: (...args: any[]) => any;
            getPopupContainer?: (...args: any[]) => any;
            notFoundContent?: VueNode;
            autofocus?: boolean;
            displayRender?: (...args: any[]) => any;
            loadData?: (...args: any[]) => any;
            expandTrigger?: "click" | "hover";
            changeOnSelect?: boolean;
            popupVisible?: boolean;
            fieldNames?: unknown;
            suffixIcon?: VueNode;
            showSearchRender?: any;
            onPopupVisibleChange?: (...args: any[]) => any;
            onSearch?: (...args: any[]) => any;
            "onUpdate:value"?: (...args: any[]) => any;
        }>, {
            configProvider: any;
            localeData: any;
            cachedOptions: any[];
            popupRef: any;
            input: any;
            formItemContext: import("../form/FormItemContext").FormItemContext;
        }, {
            sValue: any[];
            inputValue: string;
            inputFocused: boolean;
            sPopupVisible: boolean;
            flattenOptions: any[];
        }, {}, {
            savePopupRef(ref: any): void;
            highlightKeyword(str: string, keyword: string, prefixCls: string): (string | (string | JSX.Element)[])[];
            defaultRenderFilteredOption(opt: {
                inputValue: string;
                path: CascaderOptionType[];
                prefixCls: string;
                names: FilledFieldNamesType;
            }): any[];
            saveInput(node: any): void;
            handleChange(value: any, selectedOptions: CascaderOptionType[]): void;
            handlePopupVisibleChange(popupVisible: boolean): void;
            handleInputFocus(e: InputEvent): void;
            handleInputBlur(e: InputEvent): void;
            handleInputClick(e: MouseEvent & {
                nativeEvent?: any;
            }): void;
            handleKeyDown(e: KeyboardEvent): void;
            handleInputChange(e: Event): void;
            setValue(value: string[] | number[], selectedOptions?: CascaderOptionType[]): void;
            getLabel(): any;
            clearSelection(e: MouseEvent): void;
            generateFilteredOptions(prefixCls: string, renderEmpty: any): EmptyFilteredOptionsType[] | FilteredOptionsType[];
            focus(): void;
            blur(): void;
        }, {
            methods: {
                setState(state: {}, callback: any): void;
                __emit(...args: any[]): void;
            };
        }, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            disabled: boolean;
            value: unknown[];
            onFocus: (...args: any[]) => any;
            onBlur: (...args: any[]) => any;
            onChange: (...args: any[]) => any;
            prefixCls: string;
            getPopupContainer: (...args: any[]) => any;
            options: CascaderOptionType[];
            placeholder: string;
            defaultValue: unknown[];
            displayRender: (...args: any[]) => any;
            transitionName: string;
            popupStyle: {
                [key: string]: any;
            };
            popupClassName: string;
            popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
            allowClear: boolean;
            showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
            loadData: (...args: any[]) => any;
            inputPrefixCls: string;
            onPopupVisibleChange: (...args: any[]) => any;
            onSearch: (...args: any[]) => any;
            "onUpdate:value": (...args: any[]) => any;
        }> & {
            beforeCreate?: (() => void) | (() => void)[];
            created?: (() => void) | (() => void)[];
            beforeMount?: (() => void) | (() => void)[];
            mounted?: (() => void) | (() => void)[];
            beforeUpdate?: (() => void) | (() => void)[];
            updated?: (() => void) | (() => void)[];
            activated?: (() => void) | (() => void)[];
            deactivated?: (() => void) | (() => void)[];
            beforeDestroy?: (() => void) | (() => void)[];
            beforeUnmount?: (() => void) | (() => void)[];
            destroyed?: (() => void) | (() => void)[];
            unmounted?: (() => void) | (() => void)[];
            renderTracked?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            renderTriggered?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            errorCaptured?: ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>, info: string) => boolean | void) | ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>, info: string) => boolean | void)[];
        };
        $forceUpdate: () => void;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        options?: unknown;
        defaultValue?: unknown;
        value?: unknown;
        displayRender?: unknown;
        transitionName?: unknown;
        popupStyle?: unknown;
        popupClassName?: unknown;
        popupPlacement?: unknown;
        placeholder?: unknown;
        size?: unknown;
        disabled?: unknown;
        allowClear?: unknown;
        showSearch?: unknown;
        notFoundContent?: unknown;
        loadData?: unknown;
        expandTrigger?: unknown;
        changeOnSelect?: unknown;
        prefixCls?: unknown;
        inputPrefixCls?: unknown;
        getPopupContainer?: unknown;
        popupVisible?: unknown;
        fieldNames?: unknown;
        autofocus?: unknown;
        suffixIcon?: unknown;
        showSearchRender?: unknown;
        onChange?: unknown;
        onPopupVisibleChange?: unknown;
        onFocus?: unknown;
        onBlur?: unknown;
        onSearch?: unknown;
        'onUpdate:value'?: unknown;
    } & {
        disabled: boolean;
        value: unknown[];
        prefixCls: string;
        options: CascaderOptionType[];
        placeholder: string;
        defaultValue: unknown[];
        transitionName: string;
        popupStyle: {
            [key: string]: any;
        };
        popupClassName: string;
        popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
        allowClear: boolean;
        showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
        inputPrefixCls: string;
    } & {
        size?: "small" | "default" | "large";
        onFocus?: (...args: any[]) => any;
        onBlur?: (...args: any[]) => any;
        onChange?: (...args: any[]) => any;
        getPopupContainer?: (...args: any[]) => any;
        notFoundContent?: VueNode;
        autofocus?: boolean;
        displayRender?: (...args: any[]) => any;
        loadData?: (...args: any[]) => any;
        expandTrigger?: "click" | "hover";
        changeOnSelect?: boolean;
        popupVisible?: boolean;
        fieldNames?: unknown;
        suffixIcon?: VueNode;
        showSearchRender?: any;
        onPopupVisibleChange?: (...args: any[]) => any;
        onSearch?: (...args: any[]) => any;
        "onUpdate:value"?: (...args: any[]) => any;
    }> & import("vue").ShallowUnwrapRef<{
        configProvider: any;
        localeData: any;
        cachedOptions: any[];
        popupRef: any;
        input: any;
        formItemContext: import("../form/FormItemContext").FormItemContext;
    }> & {
        sValue: any[];
        inputValue: string;
        inputFocused: boolean;
        sPopupVisible: boolean;
        flattenOptions: any[];
    } & {
        [x: string]: never;
    } & {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    } & {
        savePopupRef(ref: any): void;
        highlightKeyword(str: string, keyword: string, prefixCls: string): (string | (string | JSX.Element)[])[];
        defaultRenderFilteredOption(opt: {
            inputValue: string;
            path: CascaderOptionType[];
            prefixCls: string;
            names: FilledFieldNamesType;
        }): any[];
        saveInput(node: any): void;
        handleChange(value: any, selectedOptions: CascaderOptionType[]): void;
        handlePopupVisibleChange(popupVisible: boolean): void;
        handleInputFocus(e: InputEvent): void;
        handleInputBlur(e: InputEvent): void;
        handleInputClick(e: MouseEvent & {
            nativeEvent?: any;
        }): void;
        handleKeyDown(e: KeyboardEvent): void;
        handleInputChange(e: Event): void;
        setValue(value: string[] | number[], selectedOptions?: CascaderOptionType[]): void;
        getLabel(): any;
        clearSelection(e: MouseEvent): void;
        generateFilteredOptions(prefixCls: string, renderEmpty: any): EmptyFilteredOptionsType[] | FilteredOptionsType[];
        focus(): void;
        blur(): void;
    } & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    options?: unknown;
    defaultValue?: unknown;
    value?: unknown;
    displayRender?: unknown;
    transitionName?: unknown;
    popupStyle?: unknown;
    popupClassName?: unknown;
    popupPlacement?: unknown;
    placeholder?: unknown;
    size?: unknown;
    disabled?: unknown;
    allowClear?: unknown;
    showSearch?: unknown;
    notFoundContent?: unknown;
    loadData?: unknown;
    expandTrigger?: unknown;
    changeOnSelect?: unknown;
    prefixCls?: unknown;
    inputPrefixCls?: unknown;
    getPopupContainer?: unknown;
    popupVisible?: unknown;
    fieldNames?: unknown;
    autofocus?: unknown;
    suffixIcon?: unknown;
    showSearchRender?: unknown;
    onChange?: unknown;
    onPopupVisibleChange?: unknown;
    onFocus?: unknown;
    onBlur?: unknown;
    onSearch?: unknown;
    'onUpdate:value'?: unknown;
} & {
    disabled: boolean;
    value: unknown[];
    prefixCls: string;
    options: CascaderOptionType[];
    placeholder: string;
    defaultValue: unknown[];
    transitionName: string;
    popupStyle: {
        [key: string]: any;
    };
    popupClassName: string;
    popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
    allowClear: boolean;
    showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
    inputPrefixCls: string;
} & {
    size?: "small" | "default" | "large";
    onFocus?: (...args: any[]) => any;
    onBlur?: (...args: any[]) => any;
    onChange?: (...args: any[]) => any;
    getPopupContainer?: (...args: any[]) => any;
    notFoundContent?: VueNode;
    autofocus?: boolean;
    displayRender?: (...args: any[]) => any;
    loadData?: (...args: any[]) => any;
    expandTrigger?: "click" | "hover";
    changeOnSelect?: boolean;
    popupVisible?: boolean;
    fieldNames?: unknown;
    suffixIcon?: VueNode;
    showSearchRender?: any;
    onPopupVisibleChange?: (...args: any[]) => any;
    onSearch?: (...args: any[]) => any;
    "onUpdate:value"?: (...args: any[]) => any;
}>, {
    configProvider: any;
    localeData: any;
    cachedOptions: any[];
    popupRef: any;
    input: any;
    formItemContext: import("../form/FormItemContext").FormItemContext;
}, {
    sValue: any[];
    inputValue: string;
    inputFocused: boolean;
    sPopupVisible: boolean;
    flattenOptions: any[];
}, {}, {
    savePopupRef(ref: any): void;
    highlightKeyword(str: string, keyword: string, prefixCls: string): (string | (string | JSX.Element)[])[];
    defaultRenderFilteredOption(opt: {
        inputValue: string;
        path: CascaderOptionType[];
        prefixCls: string;
        names: FilledFieldNamesType;
    }): any[];
    saveInput(node: any): void;
    handleChange(value: any, selectedOptions: CascaderOptionType[]): void;
    handlePopupVisibleChange(popupVisible: boolean): void;
    handleInputFocus(e: InputEvent): void;
    handleInputBlur(e: InputEvent): void;
    handleInputClick(e: MouseEvent & {
        nativeEvent?: any;
    }): void;
    handleKeyDown(e: KeyboardEvent): void;
    handleInputChange(e: Event): void;
    setValue(value: string[] | number[], selectedOptions?: CascaderOptionType[]): void;
    getLabel(): any;
    clearSelection(e: MouseEvent): void;
    generateFilteredOptions(prefixCls: string, renderEmpty: any): EmptyFilteredOptionsType[] | FilteredOptionsType[];
    focus(): void;
    blur(): void;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    disabled: boolean;
    value: unknown[];
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    prefixCls: string;
    getPopupContainer: (...args: any[]) => any;
    options: CascaderOptionType[];
    placeholder: string;
    defaultValue: unknown[];
    displayRender: (...args: any[]) => any;
    transitionName: string;
    popupStyle: {
        [key: string]: any;
    };
    popupClassName: string;
    popupPlacement: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
    allowClear: boolean;
    showSearch: boolean | ShowSearchType | (new (...args: any[]) => (boolean | ShowSearchType) & {}) | ((new (...args: any[]) => (boolean | ShowSearchType) & {}) | (() => boolean | ShowSearchType))[];
    loadData: (...args: any[]) => any;
    inputPrefixCls: string;
    onPopupVisibleChange: (...args: any[]) => any;
    onSearch: (...args: any[]) => any;
    "onUpdate:value": (...args: any[]) => any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & import("@vue/runtime-core").Plugin;
export default _default;
