import type { TableProps as RcTableProps } from '../vc-table/Table';
import type { SpinProps } from '../spin';
import type { TooltipProps } from '../tooltip';
import type { TableRowSelection, ColumnsType, TableCurrentDataSource, SorterResult, GetPopupContainer, TablePaginationConfig, SortOrder, TableLocale, FilterValue } from './interface';
import type { SizeType } from '../config-provider';
import type { PropType } from 'vue';
import type { DefaultRecordType } from '../vc-table/interface';
import type { ContextSlots } from './context';
export type { ColumnsType, TablePaginationConfig };
export interface TableProps<RecordType = DefaultRecordType> extends Omit<RcTableProps<RecordType>, 'transformColumns' | 'internalHooks' | 'internalRefs' | 'data' | 'columns' | 'scroll' | 'emptyText' | 'canExpandable' | 'onUpdateInternalRefs'> {
    dropdownPrefixCls?: string;
    dataSource?: RcTableProps<RecordType>['data'];
    columns?: ColumnsType<RecordType>;
    pagination?: false | TablePaginationConfig;
    loading?: boolean | SpinProps;
    size?: SizeType;
    bordered?: boolean;
    locale?: TableLocale;
    onChange?: (pagination: TablePaginationConfig, filters: Record<string, FilterValue | null>, sorter: SorterResult<RecordType> | SorterResult<RecordType>[], extra: TableCurrentDataSource<RecordType>) => void;
    rowSelection?: TableRowSelection<RecordType>;
    getPopupContainer?: GetPopupContainer;
    scroll?: RcTableProps<RecordType>['scroll'] & {
        scrollToFirstRowOnChange?: boolean;
    };
    sortDirections?: SortOrder[];
    showSorterTooltip?: boolean | TooltipProps;
}
export declare const tableProps: () => {
    prefixCls: {
        type: PropType<string>;
        default: any;
    };
    columns: {
        type: PropType<any>;
        default: any;
    };
    rowKey: {
        type: PropType<any>;
        default: any;
    };
    tableLayout: {
        type: PropType<any>;
        default: any;
    };
    rowClassName: {
        type: PropType<any>;
        default: any;
    };
    title: {
        type: PropType<any>;
        default: any;
    };
    footer: {
        type: PropType<any>;
        default: any;
    };
    id: {
        type: PropType<any>;
        default: any;
    };
    showHeader: {
        type: PropType<any>;
        default: any;
    };
    components: {
        type: PropType<any>;
        default: any;
    };
    customRow: {
        type: PropType<any>;
        default: any;
    };
    customHeaderRow: {
        type: PropType<any>;
        default: any;
    };
    direction: {
        type: PropType<any>;
        default: any;
    };
    expandFixed: {
        type: PropType<any>;
        default: any;
    };
    expandColumnWidth: {
        type: PropType<any>;
        default: any;
    };
    expandedRowKeys: {
        type: PropType<any>;
        default: any;
    };
    defaultExpandedRowKeys: {
        type: PropType<any>;
        default: any;
    };
    expandedRowRender: {
        type: PropType<any>;
        default: any;
    };
    expandRowByClick: {
        type: PropType<any>;
        default: any;
    };
    expandIcon: {
        type: PropType<any>;
        default: any;
    };
    onExpand: {
        type: PropType<any>;
        default: any;
    };
    onExpandedRowsChange: {
        type: PropType<any>;
        default: any;
    };
    defaultExpandAllRows: {
        type: PropType<any>;
        default: any;
    };
    indentSize: {
        type: PropType<any>;
        default: any;
    };
    expandIconColumnIndex: {
        type: PropType<any>;
        default: any;
    };
    expandedRowClassName: {
        type: PropType<any>;
        default: any;
    };
    childrenColumnName: {
        type: PropType<any>;
        default: any;
    };
    rowExpandable: {
        type: PropType<any>;
        default: any;
    };
    sticky: {
        type: PropType<any>;
        default: any;
    };
    dropdownPrefixCls: StringConstructor;
    dataSource: {
        type: PropType<any>;
        default: any;
    };
    pagination: {
        type: PropType<any>;
        default: any;
    };
    loading: {
        type: PropType<any>;
        default: any;
    };
    size: {
        type: PropType<any>;
        default: any;
    };
    bordered: BooleanConstructor;
    locale: {
        type: PropType<any>;
        default: any;
    };
    onChange: {
        type: PropType<(pagination: any, filters: Record<string, FilterValue | null>, sorter: SorterResult | SorterResult[], extra: any) => void>;
        default: any;
    };
    rowSelection: {
        type: PropType<any>;
        default: any;
    };
    getPopupContainer: {
        type: PropType<any>;
        default: any;
    };
    scroll: {
        type: PropType<any>;
        default: any;
    };
    sortDirections: {
        type: PropType<any[]>;
        default: any;
    };
    showSorterTooltip: {
        type: PropType<any>;
        default: any;
    };
    contextSlots: {
        type: PropType<ContextSlots>;
    };
    transformCellText: {
        type: PropType<any>;
    };
};
declare const Table: import("vue").DefineComponent<TableProps<DefaultRecordType>, {}, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, import("vue").EmitsOptions, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    [x: string]: unknown;
    [x: number]: unknown;
    dropdownPrefixCls?: unknown;
    dataSource?: unknown;
    columns?: unknown;
    pagination?: unknown;
    loading?: unknown;
    size?: unknown;
    bordered?: unknown;
    locale?: unknown;
    onChange?: unknown;
    rowSelection?: unknown;
    getPopupContainer?: unknown;
    scroll?: unknown;
    sortDirections?: unknown;
    showSorterTooltip?: unknown;
} & {
    [x: string]: any;
    [x: number]: any;
} & {}>, {
    [x: string]: any;
    [x: number]: any;
}>;
export default Table;
